/**
 *		Navigation Controller - Literal
 * 
 * 		Handles all navigation in the photoviewer 
 */
var NavigationController = {
	inDetail : false,
	slideShow : null,
	inSelect : false,
	openDetail : function(photo) {
		if(document.getElementById('selectedPhoto') !== null)
			document.getElementById('selectedPhoto').removeAttribute('id');
		photo.setAttribute('id', 'selectedPhoto');
		this.inSelect = true;
		var photoModel = new Photo(photo.getAttribute('src'),
								   photo.getAttribute('data-name'),
								   photo.getAttribute('data-date'),
								   photo.getAttribute('data-desc'),
								   photo.getAttribute('data-author'),
								   photo.getAttribute('data-type'));
		photoModel.addView();
		View.photoDetail(photoModel);
		this.inDetail = true;
	},
	closeDetail : function() {
		var darkerFrame = document.getElementById('darker');
		darkerFrame.parentNode.removeChild(darkerFrame);
		this.inDetail = false;
		if(this.slideShow != null)
			this.stopSlideShow();
	},
	nextPhoto : function() {
		var currDetail = document.getElementById('selectedPhoto');
		var newDetail = (currDetail.parentNode.nextSibling).getElementsByTagName('img')[0];
		if(newDetail === undefined)
			newDetail = document.getElementsByClassName('photothumbnail')[0].getElementsByTagName('img')[0];
		NavigationController.changeDetailPhoto(currDetail, newDetail);
	},
	previousPhoto : function() {
		var currDetail = document.getElementById('selectedPhoto');
		var newDetail = currDetail.parentNode.previousSibling;
		if(newDetail === undefined || newDetail instanceof Text || newDetail instanceof HTMLDivElement) {
			newDetail = document.getElementsByClassName('photothumbnail');
			newDetail = newDetail[(newDetail.length -1)];
		}
		newDetail = newDetail.getElementsByTagName('img')[0];
		NavigationController.changeDetailPhoto(currDetail, newDetail);
	},
	changeDetailPhoto : function(currDetail, newDetail) {
		var darkerFrame = document.getElementById('darker');
		// Change selected
		currDetail.removeAttribute('id');
		newDetail.setAttribute('id', 'selectedPhoto');

		
		var photoModel = new Photo(newDetail.getAttribute('src'),
								   newDetail.getAttribute('data-name'),
								   newDetail.getAttribute('data-date'),
								   newDetail.getAttribute('data-desc'),
								   newDetail.getAttribute('data-author'),
								   newDetail.getAttribute('data-type'));
		photoModel.addView();
		View.photoDetail(photoModel);
		darkerFrame.parentNode.removeChild(darkerFrame);
	},
	startSlideShow : function() {
		if(this.slideShow == null) {
			document.getElementById('slideshow').setAttribute('src', 'images/slideshow_run.png');
			document.getElementById('slideshow').setAttribute('onclick', 'event.stopPropagation(); NavigationController.stopSlideShow();');
			document.getElementById('slideshow').setAttribute('title', 'Stop SlideShow');
			this.slideShow = setInterval(function() {
				NavigationController.nextPhoto();
				document.getElementById('slideshow').setAttribute('src', 'images/slideshow_run.png');
				document.getElementById('slideshow').setAttribute('onclick', 'event.stopPropagation(); NavigationController.stopSlideShow();');
				document.getElementById('slideshow').setAttribute('title', 'Stop SlideShow');
			}, 7000);
		}
	},
	stopSlideShow : function() {
		clearInterval(this.slideShow);
		this.slideShow = null;
		document.getElementById('slideshow').setAttribute('src', 'images/slideshow.png');
		document.getElementById('slideshow').setAttribute('onclick', 'event.stopPropagation(); NavigationController.startSlideShow();');
		document.getElementById('slideshow').setAttribute('title', 'Start SlideShow');
	},
	selectFirstPhoto : function() {
		var photoViewer = PhotoviewerController.getContentDom();
		photoViewer.getElementsByTagName('article')[0].getElementsByTagName('img')[0].setAttribute('id', 'selectedPhoto');
		this.inSelect = true;
	},
	selectLastPhoto : function() {
		var photoViewer = PhotoviewerController.getContentDom();
		var photoFrames = photoViewer.getElementsByTagName('article');
		photoFrames[(photoFrames.length - 1)].getElementsByTagName('img')[0].setAttribute('id', 'selectedPhoto');
		this.inSelect = true;
	},
	nextSelectedPhoto : function() {
		var currentSelected = document.getElementById('selectedPhoto');
		currentSelected.removeAttribute('id');

		if(currentSelected.parentNode.nextSibling === undefined ||
		   currentSelected.parentNode.nextSibling instanceof Text ||
		   currentSelected.parentNode.nextSibling instanceof HTMLDivElement ) {
			this.selectFirstPhoto();
		} else {
			var newSelected = (currentSelected.parentNode.nextSibling).getElementsByTagName('img')[0];
			newSelected.setAttribute('id', 'selectedPhoto');
		}
	},
	previousSelectedPhoto : function() {
		var currentSelected = document.getElementById('selectedPhoto');
		currentSelected.removeAttribute('id');
		
		if(currentSelected.parentNode.previousSibling === undefined ||
		   currentSelected.parentNode.previousSibling instanceof Text ||
		   currentSelected.parentNode.previousSibling instanceof HTMLDivElement ) {
			this.selectLastPhoto();
		} else {
			var newSelected = (currentSelected.parentNode.previousSibling).getElementsByTagName('img')[0];
			newSelected.setAttribute('id', 'selectedPhoto');
		}
	},
	openSelectedDetail : function() {
		var currentSelected = document.getElementById('selectedPhoto');
		this.openDetail(currentSelected);
	},
	unselectPhoto : function() {
		var currentSelected = document.getElementById('selectedPhoto');
		if(currentSelected != null) {
			currentSelected.removeAttribute('id');
			this.inSelect = false;
		}
	}
}